#ifndef CLUT_T_H_
#define CLUT_T_H_


//
// clut_miser types used externally.
// (by raster)
//

namespace clut_miser
{

 //
 // an actual clut.
 //
 // raster uses cluts generated by clut_miser for its textures.
 // the format of a clut is:
 // pixel_type clut[pallette index][shade_range]  
 // pallete indexes are stored high, and shade levels stored low.
 // I've found that in my experiments this is more efficient than the other way around.
 // if you are doing a lot of polys whose shade is relatively constant and that use
 // many different palette entries it might be more efficient the other way.
 // 
 //
 typedef void * clut_t;

 //
 // Specifies an RGB pixel format of an output device. (e.g. 5-5-5, 5-6-5, etc)

 //
 struct pixel_format_16
 {
  // if r_place, g_place and b_place are all 0,
  // the order is asumed to be r,g,b 
  // (e.g. blue uccupies the lowest bits)
  //
  pixel_format_16(int red_bits, int green_bits, int blue_bits,
                  int r_place =0, int g_place=0, int b_place=0);


  //
  // transformation from 8-8-8 to 16 bit value is:
  //
  //        ( ( (r>>r_size_shift)  << (r_place_shift)  ) | 
  //          ( (g>>g_size_shift)  << (g_place_shift)  ) | 
  //          ( (b>>b_size_shift)  << (b_place_shift)  ) );
  //
  //
  int r_size_shift, g_size_shift, b_size_shift;
  int r_place_shift,g_place_shift,b_place_shift;
 };


 //
 // Table used by raster to perform alpha fills in 8 bit color mode.
 //
 // Generated via generator_8::create_blend_table();
 //
 struct pixel_blend_table_8
 {
   byte maps[256][256];
 };









};




#endif